/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.hbtop.terminal.impl.batch;

import org.apache.hadoop.hbase.hbtop.terminal.TerminalPrinter;

public class BatchTerminalPrinter implements TerminalPrinter {

  @Override
  public TerminalPrinter print(String value) {
    System.out.print(value);
    return this;
  }

  @Override
  public TerminalPrinter startHighlight() {
    return this;
  }

  @Override
  public TerminalPrinter stopHighlight() {
    return this;
  }

  @Override
  public TerminalPrinter startBold() {
    return this;
  }

  @Override
  public TerminalPrinter stopBold() {
    return this;
  }

  @Override
  public void endOfLine() {
    System.out.println();
  }
}
